#include "..\script_component.hpp"

/*
 * Function: forge_client_task_fnc_hostageModule
 * Author: Creedcoder, J. Schmidt
 *
 * Description:
 * Initializes the hostage module.
 *
 * Arguments:
 * 0: Logic <OBJECT> - The logic object
 * 1: Units <ARRAY> - The array of units
 * 2: Activated <BOOL> - Whether the module is activated
 *
 * Return Value:
 * None
 *
 * Example:
 * [logicObject, [unit1, unit2], true] call forge_client_task_fnc_hostageModule;
 *
 * Public: No
 */

params [["_logic", objNull, [objNull]], ["_units", [], [[]]], ["_activated", true, [true]]];

if !(_activated) exitWith {};

private _taskID = _logic getVariable ["TaskID", ""];
private _limitFail = _logic getVariable ["LimitFail", -1];
private _limitSuccess = _logic getVariable ["LimitSuccess", -1];
private _extraction = _logic getVariable ["ExtZone", ""];
private _companyFunds = _logic getVariable ["CompanyFunds", 0];
private _ratingFail = _logic getVariable ["RatingFail", 0];
private _ratingSuccess = _logic getVariable ["RatingSuccess", 0];
private _cbrn = _logic getVariable ["CBRN", false];
private _execution = _logic getVariable ["Execution", false];
private _endSuccess = _logic getVariable ["EndSuccess", false];
private _endFail = _logic getVariable ["EndFail", false];
private _timeLimit = _logic getVariable ["TimeLimit", 0];
private _cbrnZone = _logic getVariable ["CBRNZone", ""];

diag_log format ["[FORGE] Hostage Module Parameters: TaskID: %1, LimitFail: %2, LimitSuccess: %3, ExtractionZone: %4, Funds: %5, RatingFail: %6, RatingSuccess: %7, CBRN: %8, Execution: %9, EndSuccess: %10, EndFail: %11, Time: %12, CBRNZone: %13", 
    _taskID, _limitFail, _limitSuccess, _extraction, _companyFunds, _ratingFail, _ratingSuccess, _cbrn, _execution, _endSuccess, _endFail, _timeLimit, _cbrnZone];

private _syncedModules = synchronizedObjects _logic;
diag_log format ["[FORGE] Hostage Module Synced Entities: %1", _syncedModules];

private _hostageModule = (_syncedModules select { typeOf _x == "FORGE_Module_Hostages" }) select 0;
private _shooterModule = (_syncedModules select { typeOf _x == "FORGE_Module_Shooters" }) select 0;

private _hostageEntities = synchronizedObjects _hostageModule;
diag_log format ["[FORGE] Hostage Module Hostage Entities: %1", _hostageEntities];

private _shooterEntities = synchronizedObjects _shooterModule;
diag_log format ["[FORGE] Hostage Module Shooter Entities: %1", _shooterEntities];

{
    if (!isNull _x && (_x isNotEqualTo str objNull)) then {
        [_x, _taskID] spawn FUNC(makeHostage);
    };
} forEach _hostageEntities;

{
    if (!isNull _x && (_x isNotEqualTo str objNull)) then {
        [_x, _taskID] spawn FUNC(makeShooter);
    };
} forEach _shooterEntities;

if (_timeLimit == 0) then {
    [_taskID, _limitFail, _limitSuccess, _extraction, _companyFunds, _ratingFail, _ratingSuccess, [_cbrn, _execution], _endSuccess, _endFail] spawn FUNC(hostage);
} else {
    [_taskID, _limitFail, _limitSuccess, _extraction, _companyFunds, _ratingFail, _ratingSuccess, [_cbrn, _execution], _endSuccess, _endFail, _timeLimit, _cbrnZone] spawn FUNC(hostage);
};

deleteVehicle _logic;